@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: descriptive
 version: 0.9.4
-id: descriptive-0.9.4-70384d36be22a818694ea91dfeb98f75
-key: descr_KdEHYPemVGD7aR8kMkJs8y
+id: descriptive-0.9.4-0d64036b714063685e6c8fe815c24d1f
+key: descr_GlF7zdcyLeR16ooQ79t856
 license: BSD3
 copyright: 2015 Chris Done
 maintainer: chrisdone@gmail.com
@@ -23,11 +23,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
 library-dirs: /usr/lib/ghc-7.10.3/site-local/descriptive-0.9.4
 data-dir: /usr/share/arm-linux-ghc-7.10.3/descriptive-0.9.4
-hs-libraries: HSdescriptive-0.9.4-KdEHYPemVGD7aR8kMkJs8y
+hs-libraries: HSdescriptive-0.9.4-GlF7zdcyLeR16ooQ79t856
 depends:
-    aeson-0.10.0.0-3aa334e096178e3f732c7fe0cfda35e7
+    aeson-0.11.1.0-9c8ef4d36b55b55b3762b9041f2dfc23
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    bifunctors-5.2.1-f15ad2d16f9be29f17cf3cf758fe7ba6
+    bifunctors-5.2.1-854727fccb4481ffefcc20f535d6c50b
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
